@@ -67,16 +67,11 @@ DEFAULT_PID_FILENAME = 'postmaster.pid'
 
 initdb_option_map = {
 	'encoding' : '-E',
-	'locale' : '--locale',
-	'collate' : '--lc-collate',
-	'ctype' : '--lc-ctype',
-	'monetary' : '--lc-monetary',
-	'numeric' : '--lc-numeric',
-	'time' : '--lc-time',
 	'authentication' : '-A',
 	'user' : '-U',
 	# pwprompt is not supported.
-	# Cluster.init is *not* intended for interactive use.
+	# interactive use should be implemented by the application
+	# calling Cluster.init()
 }
 
 class Cluster(pg_api.Cluster):
@@ -218,7 +213,7 @@ class Cluster(pg_api.Cluster):
 			raise ClusterInitializationError(
 				"unable to find executable for cluster initialization",
 				details = {
-					'detail' : "The installation had neither 'initdb' nor 'pg_ctl'had neither 'initdb' nor 'pg_ctl'",
+					'detail' : "The installation does not have 'initdb' or 'pg_ctl'.",
 				},
 				creator = self
 			)
@@ -586,9 +581,9 @@ class Cluster(pg_api.Cluster):
 			if not self.running():
 				if self.daemon_process is not None:
 					r = self.daemon_process.returncode
-					if r is not None and r != 0:
+					if r is not None:
 						raise ClusterStartupError(
-							"postgres daemon exited with non-zero status",
+							"postgres daemon terminated",
 							details = {
 								'RESULT' : r,
 								'COMMAND' : self.daemon_command,
